==> bitcoin_0.12.1.orig.tar.gz: bitcoin-0.12.1/src/qt/locale/bitcoin_vi.ts <==
<TS language="vi" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Tạo một địa chỉ mới</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Tạo mới</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Sao chép các địa chỉ đã được chọn vào bộ nhớ tạm thời của hệ thống</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Sao chép</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Sao chép địa chỉ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Xóa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Tập tin tách biệt bởi dấu phẩy (*.csv)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Địa chỉ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chưa có nhãn)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Số lượng:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chưa có nhãn)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Địa chỉ</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Sao chép địa chỉ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Địa chỉ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chưa có nhãn)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Số lượng:</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chưa có nhãn)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Tập tin tách biệt bởi dấu phẩy (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Địa chỉ</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.13.1.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_vi.ts <==
<TS language="vi" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Tạo một địa chỉ mới</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Tạo mới</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Sao chép các địa chỉ đã được chọn vào bộ nhớ tạm thời của hệ thống</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Sao chép</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Xóa</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Số lượng:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>Nhãn dữ liệu</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Địa chỉ</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Số lượng</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Sao chép địa chỉ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Số lượng:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
